EManual-CLI
-----------

Command Line Interface for EManual

install
-------
```shell
pip install emanual
```

Usage
-----

create info.json
```shell
cd path/to/md-xxx
emanual create
````

clean up add `*.json`
```shell
emanual clean
```



Development
-----------

```shell
//create you virtual python envirment
virtualenv env
source env/bin/activate

//exit
activate
```

License
-------

MIT
